pub struct QueryResult<T> {
pub items: Vec<T>,
pub total: usize,
pub offset: usize,
}Expand description
The result of a store query, including pagination metadata.
Fields
items: Vec<T>The matched items in this page.
total: usizeTotal number of matching items before pagination was applied.
offset: usizeThe offset that was used to produce this page.
Implementations
Sourceimpl<T> QueryResult<T>
impl<T> QueryResult<T>